import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	jest.setTimeout(20000);
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('GET /api/cards sucessfully', () => {
	it('basic get should return 200', async () => {
		const res = await axios.get(base + '/api/cards', axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('GET /api/cards illegally', () => {
	it('get for non-existant track should return 404', async () => {
		const res = await axios.get(base + '/api/cards/-1', axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('adding + getting cards (no runner)', () => {
	let added_card;
	it('correct distance and runner input should return 200', async () => {
		const res = await axios.post(base + '/api/cards', null, axios_config);
		added_card = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if scans was added (no parameter validation)', async () => {
		const res = await axios.get(base + '/api/cards/' + added_card.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
});