import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    jest.setTimeout(20000);
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

// ---------------
describe('POST /api/donors with errors', () => {
    it('creating a new donor without any parameters should return 400', async () => {
        const res1 = await axios.post(base + '/api/donors', null, axios_config);
        expect(res1.status).toEqual(400);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new donor without a last name should return 400', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "middlename": "middle"
        }, axios_config);
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new donor with a invalid phone number should return 400', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "phone": "123"
        }, axios_config);
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new donor with a invalid mail address should return 400', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "phone": null,
            "email": "123",
        }, axios_config);
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new donor without an address but with receiptNeeded=true 406', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "receiptNeeded": true
        }, axios_config);
        expect(res2.status).toEqual(406);
        expect(res2.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('POST /api/donors working', () => {
    it('creating a new donor with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new donor with all non-relationship optional params should return 200', async () => {
        const res3 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "receiptNeeded": false
        }, axios_config);
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});