import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port
let access_token;
let axios_config;

beforeAll(async () => {
    jest.setTimeout(20000);
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('GET /api/donors', () => {
    it('basic get should return 200', async () => {
        const res = await axios.get(base + '/api/donors', axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/donors/0', () => {
    it('basic get should return 404', async () => {
        const res = await axios.get(base + '/api/donors/0', axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/donors after adding', () => {
    let added_donor;
    it('creating a new donor with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        added_donor = res2.data;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('explicit get should return 200', async () => {
        const res3 = await axios.get(base + '/api/donors/' + added_donor.id, axios_config);
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
        let gotten_donor = res3.data
        expect(gotten_donor).toEqual(added_donor);
    });
    it('get from all runners should return 200', async () => {
        const res4 = await axios.get(base + '/api/donors/', axios_config);
        expect(res4.status).toEqual(200);
        expect(res4.headers['content-type']).toContain("application/json")
        let gotten_donors = res4.data
        expect(gotten_donors).toContainEqual(added_donor);
    });
});