import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	jest.setTimeout(20000);
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('GET /api/stations sucessfully', () => {
	it('basic get should return 200', async () => {
		const res = await axios.get(base + '/api/stations', axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('GET /api/stations illegally', () => {
	it('get for non-existant track should return 404', async () => {
		const res = await axios.get(base + '/api/stations/-1', axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('adding + getting stations', () => {
	let added_track;
	let added_station;
	it('creating a track should return 200', async () => {
		const res1 = await axios.post(base + '/api/tracks', {
			"name": "test123",
			"distance": 123
		}, axios_config);
		added_track = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id,
			"description": "I am but a simple test."
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if station was added (no parameter validation)', async () => {
		const res = await axios.get(base + '/api/stations/' + added_station.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
});
// ---------------
describe('adding + getting via me endpoint', () => {
	let added_track;
	let added_station;
	it('creating a track should return 200', async () => {
		const res1 = await axios.post(base + '/api/tracks', {
			"name": "test123",
			"distance": 123
		}, axios_config);
		added_track = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id,
			"description": "I am but a simple test."
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.get(base + '/api/stations/me', { headers: { "authorization": "Bearer " + added_station.key } });
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
		added_station.key = "Only visible on creation.";
		expect(res.data).toEqual(added_station);
	});
});