import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    jest.setTimeout(20000);
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('POST /api/runners/me/login invalid syntax/mail should fail', () => {
    it('get without mail return 404', async () => {
        const res = await axios.post(base + '/api/runners/login', null, axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json");
    });
    it('get without bs mail return 404', async () => {
        const res = await axios.post(base + '/api/runners/login?mail=asdasdasdasdasd@tester.test.dev.lauf-fuer-kaya.de', null, axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json");
    });
});
// ---------------
describe('POST /api/runners/me/login 2 times within timeout should fail', () => {
    let added_runner;
    it('registering as citizen should return 200', async () => {
        const res = await axios.post(base + '/api/runners/register', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "email": "citizen420@dev.lauf-fuer-kaya.de"
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
        added_runner = res.data;
    });
    it('post with valid mail should return 200', async () => {
        const res = await axios.post(base + '/api/runners/login?mail=' + added_runner.email, null, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
    });
    it('2nd post with valid mail should return 406', async () => {
        const res = await axios.post(base + '/api/runners/login?mail=' + added_runner.email, null, axios_config);
        expect(res.status).toEqual(406);
        expect(res.headers['content-type']).toContain("application/json");
    });
});

// ---------------
describe('POST /api/runners/me/login valid should return 200', () => {
    let added_runner;
    let new_token;
    it('registering as citizen should return 200', async () => {
        const res = await axios.post(base + '/api/runners/register', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "email": "citizen69@dev.lauf-fuer-kaya.de"
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
        added_runner = res.data;
    });
    it('post with valid mail should return 200', async () => {
        const res = await axios.post(base + '/api/runners/login?mail=' + added_runner.email, null, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
        new_token = res.data.token;
    });
    it('get infos with valid jwt should return 200', async () => {
        const res = await axios.get(base + '/api/runners/me/' + new_token, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
    });
});
