import { faker } from '@faker-js/faker';
import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    jest.setTimeout(20000);
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('GET /api/runners/me invalid should return fail', () => {
    it('get with invalid jwt should return 401', async () => {
        const res = await axios.get(base + '/api/runners/me/123.123', axios_config);
        expect(res.status).toEqual(401);
        expect(res.headers['content-type']).toContain("application/json");
    });
});
// ---------------
describe('register + get should return 200', () => {
    let added_runner;
    it('registering as citizen should return 200', async () => {
        const res = await axios.post(base + '/api/runners/register', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "email": faker.internet.exampleEmail(),
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
        added_runner = res.data;
    });
    it('get with valid jwt should return 200', async () => {
        const res = await axios.get(base + '/api/runners/me/' + added_runner.token, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
    });
    it('get scans with valid jwt should return 200', async () => {
        const res = await axios.get(base + '/api/runners/me/' + added_runner.token + "/scans", axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json");
    });
});