import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	jest.setTimeout(20000);
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('GET /api/tracks sucessfully', () => {
	it('basic get should return 200', async () => {
		const res = await axios.get(base + '/api/tracks', axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('GET /api/tracks illegally', () => {
	it('get for non-existant track should return 404', async () => {
		const res = await axios.get(base + '/api/tracks/-1', axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('adding + getting tracks', () => {
	let added_track;
	it('correct distance input should return 200', async () => {
		const res = await axios.post(base + '/api/tracks', {
			"name": "string",
			"distance": 1000
		}, axios_config);
		added_track = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if track was added (no parameter validation)', async () => {
		const res = await axios.get(base + '/api/tracks/' + added_track.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
});