import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    jest.setTimeout(20000);
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

// ---------------
describe('adding + deletion (non-existant)', () => {
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/users/0?force=true', axios_config);
        expect(res2.status).toEqual(204);
    });
});
// ---------------
describe('adding + deletion (successfull)', () => {
    let added_user
    it('valid user creation with minimal parameters should return 200', async () => {
        const res = await axios.post(base + '/api/users', {
            "firstname": "string",
            "middlename": "string",
            "lastname": "string",
            "email": "demo_123_123_123asdASD@example.com",
            "password": "demo_123_123_123asdASD",
            "enabled": true
        }
            , axios_config);
        added_user = res.data;
        expect(res.status).toEqual(200);
    });
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/users/' + added_user.id + "?force=true", axios_config);
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('check if user really was deleted', async () => {
        const res3 = await axios.get(base + '/api/users/' + added_user.id, axios_config);
        expect(res3.status).toEqual(404);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});